PyXMake Developer Guide: PyXMake.VTL.stm_make.pyx_fortran Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | Static Public Attributes | Protected Member Functions | Protected Attributes | Static Protected Attributes | List of all members
PyXMake.VTL.stm_make.pyx_fortran Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.pyx_fortran:

## Public Member Functions
| initialize_options (self)
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)

## Public Attributes
int | verbose = 0
str | source_path = ''
str | output_file_path = ''
str | base_path = ''
| scratch_path = os.getcwd()
str | btype = 'static'
| libs = None
| includes = None
| libpaths = None
| modules = None
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose

## Static Public Attributes
str | description = "Runs the build process of Fortran source code using the Intel Fortran Compiler through Python."
list | user_options

## Protected Member Functions
| _run_command (self, command)
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_command (self)
| _perform_post_actions (self)

## Protected Attributes
dict | _MAKE_OPT = {"Python":0, "Java":1, "Fortran":2}

## Static Protected Attributes
str | _PACKAGE_NAME = ''
list | _INPUT_FILES = []

## Additional Inherited Members
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()

## Detailed Description

    Base class for encapsulating command line arguments and build process.

Definition at line 664 of file stm_make.py.

## Member Function Documentation

## ◆ _run_command()

PyXMake.VTL.stm_make.pyx_fortran._run_command | ( |  | self,
|  |  | command )
| protected

    Execute build command

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 710 of file stm_make.py.

## ◆ finalize_options()

PyXMake.VTL.stm_make.pyx_fortran.finalize_options | ( |  | self | ) |

    Post-process options.

Definition at line 699 of file stm_make.py.

## ◆ initialize_options()

PyXMake.VTL.stm_make.pyx_fortran.initialize_options | ( |  | self | ) |

    Set default values for options.

Definition at line 682 of file stm_make.py.

## Member Data Documentation

## ◆ _INPUT_FILES

list PyXMake.VTL.stm_make.pyx_fortran._INPUT_FILES = []
| staticprotected

Definition at line 669 of file stm_make.py.

## ◆ _MAKE_OPT

dict PyXMake.VTL.stm_make.pyx_fortran._MAKE_OPT = {"Python":0, "Java":1, "Fortran":2}
| protected

Definition at line 687 of file stm_make.py.

## ◆ _PACKAGE_NAME

PyXMake.VTL.stm_make.pyx_fortran._PACKAGE_NAME = ''
| staticprotected

Definition at line 668 of file stm_make.py.

## ◆ base_path

PyXMake.VTL.stm_make.pyx_fortran.base_path = ''

Definition at line 691 of file stm_make.py.

## ◆ btype

str PyXMake.VTL.stm_make.pyx_fortran.btype = 'static'

Definition at line 693 of file stm_make.py.

## ◆ description

str PyXMake.VTL.stm_make.pyx_fortran.description = "Runs the build process of Fortran source code using the Intel Fortran Compiler through Python."
| static

Definition at line 671 of file stm_make.py.

## ◆ includes

PyXMake.VTL.stm_make.pyx_fortran.includes = None

Definition at line 695 of file stm_make.py.

## ◆ libpaths

PyXMake.VTL.stm_make.pyx_fortran.libpaths = None

Definition at line 696 of file stm_make.py.

## ◆ libs

PyXMake.VTL.stm_make.pyx_fortran.libs = None

Definition at line 694 of file stm_make.py.

## ◆ modules

PyXMake.VTL.stm_make.pyx_fortran.modules = None

Definition at line 697 of file stm_make.py.

## ◆ output_file_path

str PyXMake.VTL.stm_make.pyx_fortran.output_file_path = ''

Definition at line 690 of file stm_make.py.

## ◆ scratch_path

PyXMake.VTL.stm_make.pyx_fortran.scratch_path = os.getcwd()

Definition at line 692 of file stm_make.py.

## ◆ source_path

PyXMake.VTL.stm_make.pyx_fortran.source_path = ''

Definition at line 689 of file stm_make.py.

## ◆ user_options

list PyXMake.VTL.stm_make.pyx_fortran.user_options
| static

Initial value:
= [
# The format is (long option, short option, description).
('source-path=', None, 'path to the folder holding the fortran files'),
('scratch-path=', None, 'path to scratch folder where all temporary data is located during the build event'),
('output-file-path=', None, 'path to the output directory'),
('base-path=', None, 'path to base folder - optional'),
('verbose=', None, 'controls the logging level (0 - Nothing) Default: 2 - Everything'),
('btype=', None, 'controls the building type. Defaults to static library. Use shared to indicate a dynamic library shall be created'),
]

Definition at line 672 of file stm_make.py.

## ◆ verbose

int PyXMake.VTL.stm_make.pyx_fortran.verbose = 0

Definition at line 688 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py